
# Atomic loop pkg test

This is a beta phase project package demonstrating how to create and publish a python module to pypi.

# How to Download the package ?

download the package using

```python
pip install atomic-loop-pkg-test
```

# How to import the package ?

## To import the package :

## For ex.

```py
from atomic_loop_pkg_test import functions

# create instance for the class and then specify the value of the n1 and n2 to perform the values

# i is the instance

i = functions.MathFunctions(3,2)

result = i.sum()

print(result)
```

## Thank You !!



